@@ -9,20 +9,16 @@
 use crate::messaging::client::ClientMsg;
 use crate::messaging::{
     client::{
-        ChunkRead, ChunkWrite, ClientSig, DataCmd, DataExchange, DataQuery, ProcessMsg,
-        ProcessingError, QueryResponse, SupportingInfo,
+        ChunkRead, ChunkWrite, ClientSig, DataCmd, DataExchange, DataQuery, ProcessingError,
+        QueryResponse, SupportingInfo,
     },
     node::NodeMsg,
     Aggregation, DstLocation, EndUser, MessageId, SrcLocation,
 };
 use crate::routing::Prefix;
-#[cfg(feature = "simulated-payouts")]
-use crate::types::{
-    ActorHistory, Chunk, CreditAgreementProof, NodeAge, PublicKey, RewardAccumulation,
-    RewardProposal, SignedTransfer, Transfer, TransferAgreementProof,
-};
+use crate::types::{Chunk, PublicKey};
 use std::{
-    collections::{BTreeMap, BTreeSet},
+    collections::BTreeSet,
     fmt::{Debug, Formatter},
 };
 use xor_name::XorName;
@@ -46,42 +42,6 @@ pub type NodeDuties = Vec<NodeDuty>;
 /// Common duties run by all nodes.
 #[allow(clippy::large_enum_variant)]
 pub enum NodeDuty {
-    GetNodeWalletKey {
-        node_name: XorName,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    PropagateTransfer {
-        proof: CreditAgreementProof,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    SetNodeWallet {
-        wallet_id: PublicKey,
-        node_id: XorName,
-    },
-    GetTransferReplicaEvents {
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    /// Validate a transfer from a client
-    ValidateClientTransfer {
-        signed_transfer: SignedTransfer,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    /// Register a transfer from a client
-    RegisterTransfer {
-        proof: TransferAgreementProof,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    /// TEMP: Simulate a transfer from a client
-    SimulatePayout {
-        transfer: Transfer,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
     ReadChunk {
         read: ChunkRead,
         msg_id: MessageId,
@@ -107,31 +67,6 @@ pub enum NodeDuty {
         msg_id: MessageId,
         origin: SrcLocation,
     },
-    /// Get key transfers since specified version.
-    GetTransfersHistory {
-        /// The wallet key.
-        at: PublicKey,
-        /// The last version of transfers we know of.
-        since_version: usize,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    /// Get Balance at a specific key
-    GetBalance {
-        at: PublicKey,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    GetStoreCost {
-        /// Number of bytes to write.
-        bytes: u64,
-        msg_id: MessageId,
-        origin: SrcLocation,
-    },
-    /// Proposal of payout of rewards.
-    ReceiveRewardProposal(RewardProposal),
-    /// Accumulation of payout of rewards.
-    ReceiveRewardAccumulation(RewardAccumulation),
     Genesis,
     EldersChanged {
         /// Our section prefix.
@@ -169,10 +104,6 @@ pub enum NodeDuty {
     LevelDown,
     /// Initiates the node with state from peers.
     SynchState {
-        /// The registered wallet keys for nodes earning rewards
-        node_rewards: BTreeMap<XorName, (NodeAge, PublicKey)>,
-        /// The wallets of users on the network.
-        user_wallets: BTreeMap<PublicKey, ActorHistory>,
         /// The metadata stored on Elders.
         metadata: DataExchange,
     },
@@ -220,11 +151,6 @@ pub enum NodeDuty {
         client_sig: ClientSig,
         origin: EndUser,
     },
-    /// Process Payment for a DataCmd
-    ProcessDataPayment {
-        msg: ProcessMsg,
-        origin: EndUser,
-    },
     /// Receive a chunk that is being replicated.
     /// This is run at an Adult (the new holder).
     ReplicateChunk {
@@ -250,16 +176,6 @@ impl Debug for NodeDuty {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Genesis { .. } => write!(f, "Genesis"),
-            Self::GetNodeWalletKey { .. } => write!(f, "GetNodeWalletKey"),
-            Self::PropagateTransfer { .. } => write!(f, "PropagateTransfer"),
-            Self::SetNodeWallet { .. } => write!(f, "SetNodeWallet"),
-            Self::GetTransferReplicaEvents { .. } => write!(f, "GetTransferReplicaEvents"),
-            Self::ValidateClientTransfer { .. } => write!(f, "ValidateClientTransfer"),
-            Self::RegisterTransfer { .. } => write!(f, "RegisterTransfer"),
-            Self::GetBalance { .. } => write!(f, "GetBalance"),
-            Self::GetStoreCost { .. } => write!(f, "GetStoreCost"),
-            Self::SimulatePayout { .. } => write!(f, "SimulatePayout"),
-            Self::GetTransfersHistory { .. } => write!(f, "GetTransfersHistory"),
             Self::ReadChunk { .. } => write!(f, "ReadChunk"),
             Self::WriteChunk { .. } => write!(f, "WriteChunk"),
             Self::ProcessRepublish { .. } => write!(f, "ProcessRepublish"),
@@ -272,9 +188,6 @@ impl Debug for NodeDuty {
                 "RecordAdultReadLiveness {{ correlation_id: {}, response: {:?}, src: {} }}",
                 correlation_id, response, src
             ),
-            Self::ReceiveRewardProposal { .. } => write!(f, "ReceiveRewardProposal"),
-            Self::ReceiveRewardAccumulation { .. } => write!(f, "ReceiveRewardAccumulation"),
-            // ------
             Self::LevelDown => write!(f, "LevelDown"),
             Self::SynchState { .. } => write!(f, "SynchState"),
             Self::EldersChanged { .. } => write!(f, "EldersChanged"),
@@ -301,7 +214,6 @@ impl Debug for NodeDuty {
             ),
             Self::ProcessRead { .. } => write!(f, "ProcessRead"),
             Self::ProcessWrite { .. } => write!(f, "ProcessWrite"),
-            Self::ProcessDataPayment { .. } => write!(f, "ProcessDataPayment"),
             Self::ReplicateChunk { .. } => write!(f, "ReplicateChunk"),
             Self::ProposeOffline(nodes) => write!(f, "ProposeOffline({:?})", nodes),
         }
